@@ -2,7 +2,7 @@
 #
 # Module  : Def.pm
 # Purpose : Definition structure.
-# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -135,8 +135,8 @@ sub equals {
 	my ($self, $target) = @_;
 	my $result = 0;
 	if ($target) {
-		die "The text of this definition is undefined." if (!defined($self->{TEXT}));
-		die "The text of the target definition is undefined." if (!defined($target->{TEXT}));
+		die 'The text of this definition is undefined.' if (!defined($self->{TEXT}));
+		die 'The text of the target definition is undefined.' if (!defined($target->{TEXT}));
 
 		$result = (($self->{TEXT} eq $target->{TEXT}) && ($self->{DBXREF_SET}->equals($target->{DBXREF_SET})));
 	}
@@ -250,7 +250,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
