@@ -2,7 +2,7 @@
 #
 # Module  : SynonymTypeDef.pm
 # Purpose : A synonym type definition.
-# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -103,11 +103,11 @@ sub equals {
 	my $result = 0;
 	if ($target) {
 		
-		die "The synonym type name of this synonym type definition is undefined." if (!defined($self->{NAME}));
-		die "The synonym type name of the target synonym type definition is undefined." if (!defined($self->{NAME}));
+		die 'The synonym type name of this synonym type definition is undefined.' if (!defined($self->{NAME}));
+		die 'The synonym type name of the target synonym type definition is undefined.' if (!defined($self->{NAME}));
 		
-		die "The description of the this synonym type definition is undefined." if (!defined($target->{DESCRIPTION}));
-		die "The description of the target synonym type definition is undefined." if (!defined($target->{DESCRIPTION}));
+		die 'The description of the this synonym type definition is undefined.' if (!defined($target->{DESCRIPTION}));
+		die 'The description of the target synonym type definition is undefined.' if (!defined($target->{DESCRIPTION}));
 		
 		$result = ($self->{NAME} eq $target->{NAME}) && ($self->{DESCRIPTION} eq $target->{DESCRIPTION});
 		$result = $result && ($self->{SCOPE} eq $target->{SCOPE}) if (defined $self->{SCOPE} && defined $target->{SCOPE}); # TODO Future improvement, consider case: scope_1 undefined and scope_2 defined!
@@ -183,7 +183,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
