@@ -2,7 +2,7 @@
 #
 # Module  : Term.pm
 # Purpose : Term in the Ontology.
-# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -307,9 +307,9 @@ sub subset {
 sub synonym_set {
 	my $self = shift;
 	foreach my $synonym (@_) {
-		die "The name of this term (", $self->id(), ") is undefined" if (!defined($self->name()));
+		die 'The name of this term (', $self->id(), ') is undefined.' if (!defined($self->name()));
 		# do not add 'EXACT' synonyms with the same 'name':
-		$self->{SYNONYM_SET}->add($synonym) if (!($synonym->scope() eq "EXACT" && $synonym->def()->text() eq $self->name()));
+		$self->{SYNONYM_SET}->add($synonym) if (!($synonym->scope() eq 'EXACT' && $synonym->def()->text() eq $self->name()));
    	}
 	return $self->{SYNONYM_SET}->get_set();
 }
@@ -838,7 +838,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
